/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.onos.yang.yangautoprefix10.level1.newlevel.rev20150205.moduletest;

import com.google.common.base.MoreObjects;
import java.util.List;
import java.util.Objects;
import org.onosproject.yang.gen.v1.onos.yang.yangautoprefix10.level1.newlevel.rev20150205.moduletest.xml.Person;

/**
 * Represents the builder implementation of xmL.
 */
public class XmLBuilder implements XmL.XmLBuilder {

    private List<Person> person;

    @Override
    public List<Person> person() {
        return person;
    }

    @Override
    public XmLBuilder person(List<Person> person) {
        this.person = person;
        return this;
    }

    @Override
    public XmL build() {
        return new XmLImpl(this);
    }

    /**
     * Creates an instance of xmLbuilder.
     */
    public XmLBuilder() {
    }


    /**
     * Represents the implementation of xmL.
     */
    public final class XmLImpl implements XmL {

        private List<Person> person;

        @Override
        public List<Person> person() {
            return person;
        }

        @Override
        public int hashCode() {
            return Objects.hash(person);
        }

        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (obj instanceof XmLImpl) {
                XmLImpl other = (XmLImpl) obj;
                return
                     Objects.equals(person, other.person);
            }
            return false;
        }

        @Override
        public String toString() {
            return MoreObjects.toStringHelper(getClass())
                .add("person", person)
                .toString();
        }

        /**
         * Creates an instance of xmLImpl.
         *
         * @param builderObject builder object of xmL
         */
        public XmLImpl(XmLBuilder builderObject) {
            this.person = builderObject.person();
        }
    }
}