/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.onos.yang.yangautoprefix10.level1.newlevel.rev20150205.moduletest.xml;

import com.google.common.base.MoreObjects;
import java.util.Objects;

/**
 * Represents the builder implementation of person.
 */
public class PersonBuilder implements Person.PersonBuilder {

    private String name;
    private String place;

    @Override
    public String name() {
        return name;
    }

    @Override
    public String place() {
        return place;
    }

    @Override
    public PersonBuilder name(String name) {
        this.name = name;
        return this;
    }

    @Override
    public PersonBuilder place(String place) {
        this.place = place;
        return this;
    }

    @Override
    public Person build() {
        return new PersonImpl(this);
    }

    /**
     * Creates an instance of personBuilder.
     */
    public PersonBuilder() {
    }


    /**
     * Represents the implementation of person.
     */
    public final class PersonImpl implements Person {

        private String name;
        private String place;

        @Override
        public String name() {
            return name;
        }

        @Override
        public String place() {
            return place;
        }

        @Override
        public int hashCode() {
            return Objects.hash(name, place);
        }

        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (obj instanceof PersonImpl) {
                PersonImpl other = (PersonImpl) obj;
                return
                     Objects.equals(name, other.name) &&
                     Objects.equals(place, other.place);
            }
            return false;
        }

        @Override
        public String toString() {
            return MoreObjects.toStringHelper(getClass())
                .add("name", name)
                .add("place", place)
                .toString();
        }

        /**
         * Creates an instance of personImpl.
         *
         * @param builderObject builder object of person
         */
        public PersonImpl(PersonBuilder builderObject) {
            this.name = builderObject.name();
            this.place = builderObject.place();
        }
    }
}